# delimit;
clear all;
set mem 1G;

local data_dir "Data";
local out_dir "Output";
local fig_dir "Figures";
local tab_dir "Tables";

/*
use "`data_dir'\HS92_imports_least_1995.dta", replace;
local out_file "`tab_dir'\reg_hs_1995.txt";
local figure "\HS_figure";
local thresh "520";
*/

use "`data_dir'\SITC_imports_least_1995.dta",replace;
local out_file "`tab_dir'\reg_sitc_1995.txt";
local figure "\fig2";
local thresh "184";

**Add country names.**************************************************;
rename exporter countrycode;
merge m:1 countrycode using "`data_dir'\names.dta", keepusing(iso3digitalpha oecd);
rename countrycode exporter;
rename iso3digitalpha iso_ex;
rename oecd oecd_ex;
drop if _merge !=3;
drop _merge;

rename importer countrycode;
merge m:1 countrycode using "`data_dir'\names.dta", keepusing(iso3digitalpha oecd);
rename countrycode importer;
rename iso3digitalpha iso_im;
rename oecd oecd_im;
drop if _merge !=3;
drop _merge;

*****Add trade agreement variables;
rename iso_im iso3_d;
rename iso_ex iso3_o;
merge m:1 iso3_d iso3_o using "`data_dir'\cepii_1995.dta", keepusing(gatt_o gatt_d rta);

rename gatt_o gatt_o_95;
rename gatt_d gatt_d_95;
rename rta rta_95;
drop if _merge==2;
drop  _merge;

merge m:1 iso3_d iso3_o using "`data_dir'\cepii_2005.dta",keepusing(gatt_o gatt_d rta);
rename gatt_o gatt_o_05;
rename gatt_d gatt_d_05;
rename rta rta_05;
drop if _merge==2;
drop  _merge;

rename iso3_d iso_im ;
rename iso3_o iso_ex;

**Add GDP per capita data;
rename iso_im iso;
merge m:1 iso using "`data_dir'\rgdpl_WDI.dta";
rename rgdpl_95 rgdpl_95_im;
rename rgdpl_05 rgdpl_05_im;
rename iso iso_im;
drop if _merge==2;
drop _merge;

rename iso_ex iso;
merge m:1 iso using "`data_dir'\rgdpl_WDI.dta";
rename rgdpl_95 rgdpl_95_ex;
rename rgdpl_05 rgdpl_05_ex;
rename iso iso_ex;
drop if _merge==2;
drop _merge;


gen pair = iso_ex + "-" + iso_im;

**Drop countries with too few initially exported varieties, or with growth rates too large;
**This is too large to bind;
local val_thresh "5000000000";

gen sample = 1;

**Drop the world (0) and not otherwise specified (899) and other asia(490);
replace sample = 0 if importer == 0;
replace sample = 0 if exporter == 0;
replace sample = 0 if importer == 490;
replace sample = 0 if exporter == 490;
replace sample = 0 if importer == 899;
replace sample = 0 if exporter == 899;
replace sample = 0 if importer == 891;
replace sample = 0 if exporter == 891;

replace sample = 0 if least_goods_1995 < `thresh';

replace sample = 0 if growth_least_y1_y11 > `val_thresh' | growth_least_y1_y11==.;
replace sample = 0 if growth_total_y1_y11 > `val_thresh' | growth_total_y1_y11==.;
replace sample = 0 if growth_least_y1_y10 > `val_thresh' | growth_least_y1_y10==.;
replace sample = 0 if growth_total_y1_y10 > `val_thresh' | growth_total_y1_y10==.;
replace sample = 0 if growth_least_y1_y9 > `val_thresh' | growth_least_y1_y9==.;
replace sample = 0 if growth_total_y1_y9 > `val_thresh' | growth_total_y1_y9==.;
replace sample = 0 if growth_least_y1_y8 > `val_thresh' | growth_least_y1_y8==.;
replace sample = 0 if growth_total_y1_y8 > `val_thresh' | growth_total_y1_y8==.;
replace sample = 0 if growth_least_y1_y7 > `val_thresh' | growth_least_y1_y7==.;
replace sample = 0 if growth_total_y1_y7 > `val_thresh' | growth_total_y1_y7==.;
replace sample = 0 if growth_least_y1_y6 > `val_thresh' | growth_least_y1_y6==.;
replace sample = 0 if growth_total_y1_y6 > `val_thresh' | growth_total_y1_y6==.;
replace sample = 0 if growth_least_y1_y5 > `val_thresh' | growth_least_y1_y5==.;
replace sample = 0 if growth_total_y1_y5 > `val_thresh' | growth_total_y1_y5==.;
replace sample = 0 if growth_least_y1_y4 > `val_thresh' | growth_least_y1_y4==.;
replace sample = 0 if growth_total_y1_y4 > `val_thresh' | growth_total_y1_y4==.;
replace sample = 0 if growth_least_y1_y3 > `val_thresh' | growth_least_y1_y3==.;
replace sample = 0 if growth_total_y1_y3 > `val_thresh' | growth_total_y1_y3==.;
replace sample = 0 if growth_least_y1_y2 > `val_thresh' | growth_least_y1_y2==.;
replace sample = 0 if growth_total_y1_y2 > `val_thresh' | growth_total_y1_y2==.;


**How big is the sample?*******************************************************;
sum total_1995 if (importer!= 0) & (exporter!=0);
local world_95 = `r(sum)';

sum total_2005 if (importer!= 0) & (exporter!=0);
local world_05 = `r(sum)';

sum total_1995 if (sample==1);
local sample_share_95 = `r(sum)' / `world_95';

sum total_2005 if (sample==1);
local sample_share_05 = `r(sum)' / `world_05';
di `sample_share_95';
di `sample_share_05';
********************************************************************************;

*****Generate stuctural growth episodes, new GATT/WTO members, new RTA**********;
gen struct_ex = 0;
gen struct_im = 0;
replace struct_ex = 1 if ln(rgdpl_05_ex/rgdpl_95_ex)/10*100 > 4;
replace struct_im = 1 if ln(rgdpl_05_im/rgdpl_95_im)/10*100 > 4;
replace struct_ex = 0 if iso_ex == "PRK" | iso_ex == "ANT";
replace struct_im = 0 if iso_ex == "PRK" | iso_ex == "ANT";

gen new_gatt_ex=0;
gen new_gatt_im=0;
replace new_gatt_ex = 1 if gatt_o_05-gatt_o_95==1;
replace new_gatt_im = 1 if gatt_d_05-gatt_d_95==1;

gen new_rta=0;
replace new_rta = 1 if rta_05-rta_95 == 1;


*****************Generate table 1*****************************************************;
file open fout using "`tab_dir'\table1.txt" , write replace;
file write fout _tab "Total Trade Growth" _tab _tab _tab _tab _tab "New Goods Trade Growth" _newline;
file write fout _tab "N" _tab "mean" _tab "sd" _tab "p25" _tab "p50" _tab "p75" _tab "mean" _tab "sd" _tab "p25" _tab "p50" _tab "p75" _newline;
sum growth_total_y1_y11 if sample==1, detail;
file write fout "All country pairs" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if oecd_ex==1 & oecd_im==1 & sample==1, detail;
file write fout "OECD importer and exporter" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if oecd_ex==1 & oecd_im==1 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if oecd_ex==1 & oecd_im==0 & sample==1, detail;
file write fout "OECD exporter and non-OECD importer" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if oecd_ex==1 & oecd_im==0 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if oecd_ex==0 & oecd_im==1 & sample==1, detail;
file write fout "non-OECD exporter and OECD importer" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if oecd_ex==0 & oecd_im==1 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if oecd_ex==0 & oecd_im==0 & sample==1, detail;
file write fout "non-OECD exporter and importer" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if oecd_ex==0 & oecd_im==0 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

file write fout _newline;
sum growth_total_y1_y11 if struct_ex==1 & struct_im==0 & sample==1, detail;
file write fout "Fast growing exporter, slow importer" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";;
sum growth_least_y1_y11 if struct_ex==1 & struct_im==0 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if struct_ex==1 & struct_im==1 & sample==1, detail;
file write fout "Fast growing exporter, fast growing importer" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";;
sum growth_least_y1_y11 if struct_ex==1 & struct_im==1 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if struct_ex==0 & struct_im==1 & sample==1, detail;
file write fout "Slow growing exporter, fast growing importer" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";;
sum growth_least_y1_y11 if struct_ex==0 & struct_im==1 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if struct_ex==0 & struct_im==0 & sample==1, detail;
file write fout "Slow growing exporter, slow growing importer" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";;
sum growth_least_y1_y11 if struct_ex==0 & struct_im==0 & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;


file write fout _newline;
sum growth_total_y1_y11 if (new_gatt_ex==1) & sample==1, detail;
file write fout "Exporter joined GATT/WTO" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if (new_gatt_ex==1) & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if (new_gatt_im==1) & sample==1, detail;
file write fout "Importer joined GATT/WTO" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if (new_gatt_im==1) & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if (new_gatt_im==0 | new_gatt_ex==0) & sample==1, detail;
file write fout "No change in GATT/WTO either party" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if (new_gatt_im==0 | new_gatt_ex==0) & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;


file write fout _newline;
sum growth_total_y1_y11 if (new_rta==1) & sample==1, detail;
file write fout "RTA forms in period" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if (new_rta==1) & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;

sum growth_total_y1_y11 if (new_rta==0) & sample==1, detail;
file write fout "No new RTA in period" _tab "`r(N)'" _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'";
sum growth_least_y1_y11 if (new_rta==0) & sample==1, detail;
file write fout _tab "`r(mean)'" _tab "`r(sd)'" _tab "`r(p25)'" _tab "`r(p50)'" _tab "`r(p75)'" _newline;
file close fout;


**Figure 2: Plot the data and the OLS line for 11 year lag.*******************************************************;
gen xy_lab = pair;

**only label these points.;
replace xy_lab = "" if (pair != "CHN-MEX") & (pair != "CHN-HUN") & (pair != "KOR-SVK") & (pair != "ARE-NLD") 
                   & (pair != "KOR-ITA") & (pair != "IND-CHN") & (pair != "PHL-CHN") & (pair != "CHN-HRV") & (pair != "PHL-MEX") ;

gen growth_least_y1_y11_pc  =  growth_least_y1_y11 * 100;
gen growth_total_y1_y11_pc  =  growth_total_y1_y11 * 100;

graph set window fontface "Arial";
twoway (scatter growth_least_y1_y11_pc growth_total_y1_y11_pc if sample==1, msymbol(o) c(i) mcolor(black)  ml(xy_lab) mlabc(black) mlabs(vsmall) )
		(lfit growth_least_y1_y11_pc growth_total_y1_y11_pc if sample==1, lc(black))
		,
		legend(off)
		xsize(6)
		ysize(3.5)
		ytitle("least-traded goods growth rate (percent)", margin(medsmall)) 
		xtitle("total trade growth rate (percent)", margin(medsmall))
		ylab(,nogrid tp(crossing) )
		xlab(0(1000)6000,nogrid tp(crossing) )
		plotregion(lstyle(none) margin(sides) color(white) )
		graphregion(color(white) 
);
graph export `fig_dir'`figure'.eps, replace;


****Table 2 *******************************************************************************************************;
** regress total export growth on least traded growth;
reg growth_least_y1_y11 growth_total_y1_y11 if sample==1, robust noconstant;
outreg2  using `out_file', replace;
reg growth_least_y1_y10 growth_total_y1_y10 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y9 growth_total_y1_y9 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y8 growth_total_y1_y8 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y7 growth_total_y1_y7 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y6 growth_total_y1_y6 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y5 growth_total_y1_y5 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y4 growth_total_y1_y4 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y3 growth_total_y1_y3 if sample==1, robust noconstant;
outreg2  using `out_file', append;
reg growth_least_y1_y2 growth_total_y1_y2 if sample==1, robust noconstant;
outreg2  using `out_file', append;

























